#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:           qubes-kernel-vm-support
Version:        4.2.5
Release:        1%{?dist}
Summary:        Qubes VM initramfs modules
Source0:        qubes-utils-%{version}.tar.gz

Group:          Qubes
Vendor:         Invisible Things Lab
License:        GPL v2 only
URL:            http://www.qubes-os.org

# qubes-prepare-vm-kernel interface version - to use in kernel.spec
Provides:       qubes-prepare-vm-kernel = 2
Requires:       dracut
Requires:       busybox
Requires:       e2fsprogs
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  e2fsprogs-devel

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%build
make -C kernel-modules all

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/lib/qubes/vm-modules-genfs
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub\.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Fri Jan 27 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils.git

* Fri Jan 27 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - eabce35
- version 4.2.5

* Mon Jan 16 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0a8ded9
- qubes-prepare-vm-kernel: make resize2fs work even if system time is off

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b066dda
- version 4.2.4

* Sat Jan 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4146e47
- dracut: detect VM based on file presence, no runtime query to qubesdb

* Sat Jan 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5a57da2
- dracut: drop legacy xenstore-read qubes-vm-type

* Sat Jan 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 21ce787
- rpm: add e2fsprogs as qubes-prepare-vm-kernel dependency

* Fri Jan 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8081c8b
- version 4.2.3

* Fri Jan 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ea27ab
- rpm: provide virtual qubes-prepare-vm-kernel capability

* Fri Jan 06 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6ea1bb4
- qubes-prepare-vm-kernel: make initramfs smaller

* Thu Jan 05 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c3fcb0f
- qubes-prepare-vm-kernel: sync with pre-built package features

* Thu Jan 05 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fbfdc05
- Build and install vm-modules-genfs

* Wed Jan 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0c95cc2
- debian: do not install qubes-prepare-vm-kernel

* Sun Jan 01 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4eb2960
- version 4.2.2

* Fri Dec 30 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 631eb0c
- SELinux policy for meminfo-writer

* Thu Dec 08 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a264344
- version 4.2.1

* Wed Nov 30 2022 Mateusz Piórkowski <mati7337@protonmail.ch> - 4ef2bc0
- Replace ImageMagick with GraphicsMagick

* Tue Oct 11 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 37a6461
- version 4.2.0

* Fri May 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 035537e
- Add spaces after function names

* Fri May 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 325ec5a
- Install and source grub.qubes-kernel-vm-support

* Fri May 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 2104b68
- Ensure that /etc/default/grub is not empty

* Fri May 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7964600
- Add comments to /etc/default/grub

* Fri May 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 6a1b9c9
- Fix up /etc/default/grub in postinstall script

* Fri May 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 42bfe8c
- Fix sed regex for mkinitcpio.conf

* Thu May 19 2022 Rusty Bird <rustybird@net-c.com> - 47db4b9
- initramfs: sector-size agnostic partitioning of volatile volume

* Thu May 19 2022 Rusty Bird <rustybird@net-c.com> - 31a90cb
- initramfs: remove unused variable

* Mon May 09 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cc4e241
- .qubesbuilder: replace 'spec' by 'build'

* Mon Apr 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 56777a2
- Add Qubes Builder v2 integration

* Fri Apr 15 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 15d4e4c
- Drop Travis CI

* Tue Dec 28 2021 Gaurav <g.gupta@samsung.com> - 77b147e
- Make use of static variables

* Tue Oct 19 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 506594e
- version 4.1.16

* Fri Oct 15 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 5be2b83
- spec: allow matching python3.10 in %files

* Fri Jun 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 07ea7b2
- version 4.1.15

* Thu May 13 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 308d708
- version 4.1.14

* Wed May 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0209684
- Force exporting of loop devices

* Tue May 11 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 546e0c9
- Add do_unpack_ext to limit what can be unpacked

* Mon Apr 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 54afa23
- Use a flexable array member instead of an empty array

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c16c721
- kernel-vm-support: fix spec indentation

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a26b504
- kernel-vm-support: add make as BR

* Fri Feb 05 2021 Shawn Anastasio <shawn@anastas.io> - ac0e7bb
- Makefile: remove broken 32-bit host check

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 72458b4
- version 4.1.13

* Tue Jan 05 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 685d201
- Fix CI

* Tue Jan 05 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - a8ca815
- Mass replace: ‘/var/run’ → ‘/run’

* Tue Jan 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1eff32a
- archlinux: add makedepends on qubes-vm-xen

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - e872754
- Validate remote filename before displaying it

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 87ead86
- Modernize systemd unit files

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - cf009e8
- Meminfo writer comes before user logins

* Fri Dec 18 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - befbd65
- Fix some links to more modern versions

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a7e3632
- debian: update compat

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6154498
- debian: update control

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8289227
- tests: fix IncompleteReadError exception location

